.. highlight:: shell

============
Installation
============


Stable release
--------------

The stable release is distributed for all Equinor users through
``/project/res``. Eventually it will be distribued through Komodo,
with access to stable, testing and bleeding versions.


For developers
--------------

The sources for fmu-ensemble can be downloaded from github.

You can either clone the public repository:

.. code-block:: console

    $ git clone https://github.com/equinor/fmu-ensemble

Once you have a copy of the source, and you have a `virtual environment`_,
you can install it with:

.. code-block:: console

    $ make install


.. _virtual environment: http://docs.python-guide.org/en/latest/dev/virtualenvs/
